//------------------------------------------------------------------------------
// File main.c
//------------------------------------------------------------------------------
// Copyright (c) 2010, Texas Instruments Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//     * Redistributions of source code must retain the above copyright notice,
//       this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright
//       notice, this list of conditions and the following disclaimer in the
//       documentation and/or other materials provided with the distribution.
//     * Neither the name of the Texas Instruments Inc. nor the names of its
//       contributors may be used to endorse or promote products derived from
//       this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
//------------------------------------------------------------------------------

#include "app.h"
#include "edma3.h"

extern cregister volatile unsigned int    ICR;    // interrupt clear register
extern cregister volatile unsigned int    IER;    // interrupt enable register

//-----------------------------------------------------------------------------
// Application Main Function
//-----------------------------------------------------------------------------

int main()
{
    // initialize EVM, EDMA
    EVMC6747_init();
    edmaInit();

    // initialize static semaphores
    SEM_new(&xmt_ping_sem, 0);
    SEM_new(&xmt_pong_sem, 0);
    SEM_new(&rcv_ping_sem, 0);
    SEM_new(&rcv_pong_sem, 0);

    // enable interrupts
    ICR  = (1 << 8);         // clear INT8 (precaution)
    IER |= (1 << 8);         // enable INT8 as CPU interrupt 
    IER |= (1 << 11);        // enable RTDX interrupts
    IER |= (1 << 12);        // enable RTDX interrupts

    // exit to static TSK
    LOG_printf(&trace, "[main]: exiting main...");
    return 0;
}

//------------------------------------------------------------------------------
// End of File main.c
//------------------------------------------------------------------------------
